@@ -30,7 +30,9 @@
 
 #include <locale>
 
-_GLIBCXX_BEGIN_NAMESPACE(std)
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   // Specializations
   template<>
@@ -45,4 +47,5 @@ _GLIBCXX_BEGIN_NAMESPACE(std)
     { return __dfault; }
 #endif
 
-_GLIBCXX_END_NAMESPACE
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace
